@@ -421,8 +421,9 @@ class ParallelMaster(GenericMaster):
         Returns:
             yield: Yield of GenericJob or JobCore
         """
+        project_working_directory = self.project.open(self.job_name + "_hdf5")
         for job_id in self._get_jobs_sorted():
-            yield self.project.load(job_id, convert_to_object=convert_to_object)
+            yield project_working_directory.load(job_id, convert_to_object=convert_to_object)
 
     def _get_jobs_sorted(self):
         job_names = self.child_names.values()
