@@ -64,8 +64,8 @@ class Settings(with_metaclass(Singleton)):
         # Default config dictionary
         self._configuration = {
             "user": "pyiron",
-            "resource_paths": ["~/pyiron/resources"],
-            "project_paths": ["~/pyiron/projects"],
+            "resource_paths": [],
+            "project_paths": [],
             "sql_connection_string": None,
             "sql_table_name": "jobs_pyiron",
             "sql_view_connection_string": None,
@@ -93,12 +93,15 @@ class Settings(with_metaclass(Singleton)):
                 config=self._configuration
             )
         else:
-            print("Fall back to default configuration: "
-                  "{'resource_paths': ['~/pyiron/resources'], "
-                  "'project_paths': ['~/pyiron/projects']}")
+            self._configuration["sql_file"] = "~/pyiron.db"
+            self._configuration["project_check_enabled"] = False
 
         # Take dictionary as primary source - overwrite everything
         self._read_external_config(config=config)
+        if "CONDA_PREFIX" in environment.keys() and os.path.exists(os.path.join(environment["CONDA_PREFIX"], "share", "pyiron")):
+            self._configuration["resource_paths"].append(os.path.join(environment["CONDA_PREFIX"], "share", "pyiron"))
+        elif "CONDA_DIR" in environment.keys() and os.path.exists(os.path.join(environment["CONDA_DIR"], "share", "pyiron")):
+            self._configuration["resource_paths"].append(os.path.join(environment["CONDA_DIR"], "share", "pyiron"))
 
         self._configuration["project_paths"] = [
             convert_path(path) + "/" if path[-1] != "/" else convert_path(path)
@@ -388,7 +391,7 @@ class Settings(with_metaclass(Singleton)):
         if parser.has_option(section, "RESOURCE_PATHS"):
             self._configuration["resource_paths"] = [
                 convert_path(c.strip())
-                for c in parser.get(section, "RESOURCE_PATHS").split(",")
+                for c in parser.get(section, "RESOURCE_PATHS").replace(",", ":").replace(";", ":").split(":")
             ]
         if self._configuration["sql_type"] in ["Postgres", "MySQL"]:
             if (
@@ -528,7 +531,7 @@ class Settings(with_metaclass(Singleton)):
                 if k in ["PYIRONPROJECTCHECKENABLED", "PYIRONDISABLE"]:
                     config[v] = environment[k].lower() in ['t', 'true', 'y', 'yes']
                 elif k in ["PYIRONRESOURCEPATHS", "PYIRONPROJECTPATHS"]:
-                    config[v] = environment[k].split(':')
+                    config[v] = environment[k].replace(",", ":").replace(";", ":").split(':')
                 else:
                     config[v] = environment[k]
         return config
